@@ -1,9 +1,13 @@
+from django.contrib.auth import get_user_model
 import factory
 from feincms.module.page.models import Page
 
 from . import content, models
 
 
+User = get_user_model()
+
+
 class DummyFactory(factory.DjangoModelFactory):
     FACTORY_FOR = models.Dummy
 
@@ -19,3 +23,9 @@ class PageFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Page
 
     title = factory.Sequence('Page {}'.format)
+
+
+class UserFactory(factory.DjangoModelFactory):
+    FACTORY_FOR = User
+
+    email = factory.Sequence('{}@example.com'.format)
